@@ -14,6 +14,7 @@
  * GNU General Public License for more details at www.gnu.org
  *
  */
+#include "config.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -134,7 +135,6 @@ struct ios_ops *can_init(char *interface_id)
 	ios->set_flow = can_set_flow;
 	ios->send_break = can_send_break;
 	ios->exit = can_exit;
-	ios->istelnet = false;
 
 	/*
 	 * the string is supposed to be formated this way:
